@@ -1,4 +1,5 @@
 from __future__ import absolute_import, division, print_function
+
 import pytest
 
 from _pytest.main import EXIT_NOTESTSCOLLECTED
@@ -45,9 +46,9 @@ class SessionTests(object):
             a = 1
         """)
         reprec = testdir.inline_run(tfile)
-        l = reprec.getfailedcollections()
-        assert len(l) == 1
-        out = str(l[0].longrepr)
+        values = reprec.getfailedcollections()
+        assert len(values) == 1
+        out = str(values[0].longrepr)
         assert out.find('does_not_work') != -1
 
     def test_raises_output(self, testdir):
@@ -75,9 +76,9 @@ class SessionTests(object):
 
     def test_syntax_error_module(self, testdir):
         reprec = testdir.inline_runsource("this is really not python")
-        l = reprec.getfailedcollections()
-        assert len(l) == 1
-        out = str(l[0].longrepr)
+        values = reprec.getfailedcollections()
+        assert len(values) == 1
+        out = str(values[0].longrepr)
         assert out.find(str('not python')) != -1
 
     def test_exit_first_problem(self, testdir):
@@ -144,15 +145,15 @@ class TestNewSession(SessionTests):
 
     def test_order_of_execution(self, testdir):
         reprec = testdir.inline_runsource("""
-            l = []
+            values = []
             def test_1():
-                l.append(1)
+                values.append(1)
             def test_2():
-                l.append(2)
+                values.append(2)
             def test_3():
-                assert l == [1,2]
+                assert values == [1,2]
             class Testmygroup(object):
-                reslist = l
+                reslist = values
                 def test_1(self):
                     self.reslist.append(1)
                 def test_2(self):
@@ -239,17 +240,60 @@ def test_exclude(testdir):
     result.stdout.fnmatch_lines(["*1 passed*"])
 
 
+def test_deselect(testdir):
+    testdir.makepyfile(test_a="""
+        import pytest
+        def test_a1(): pass
+        @pytest.mark.parametrize('b', range(3))
+        def test_a2(b): pass
+    """)
+    result = testdir.runpytest("-v", "--deselect=test_a.py::test_a2[1]", "--deselect=test_a.py::test_a2[2]")
+    assert result.ret == 0
+    result.stdout.fnmatch_lines(["*2 passed, 2 deselected*"])
+    for line in result.stdout.lines:
+        assert not line.startswith(('test_a.py::test_a2[1]', 'test_a.py::test_a2[2]'))
+
+
 def test_sessionfinish_with_start(testdir):
     testdir.makeconftest("""
         import os
-        l = []
+        values = []
         def pytest_sessionstart():
-            l.append(os.getcwd())
+            values.append(os.getcwd())
             os.chdir("..")
 
         def pytest_sessionfinish():
-            assert l[0] == os.getcwd()
+            assert values[0] == os.getcwd()
 
     """)
     res = testdir.runpytest("--collect-only")
     assert res.ret == EXIT_NOTESTSCOLLECTED
+
+
+@pytest.mark.parametrize("path", ["root", "{relative}/root", "{environment}/root"])
+def test_rootdir_option_arg(testdir, monkeypatch, path):
+    monkeypatch.setenv('PY_ROOTDIR_PATH', str(testdir.tmpdir))
+    path = path.format(relative=str(testdir.tmpdir),
+                       environment='$PY_ROOTDIR_PATH')
+
+    rootdir = testdir.mkdir("root")
+    rootdir.mkdir("tests")
+    testdir.makepyfile("""
+        import os
+        def test_one():
+            assert 1
+    """)
+
+    result = testdir.runpytest("--rootdir={}".format(path))
+    result.stdout.fnmatch_lines(['*rootdir: {}/root, inifile:*'.format(testdir.tmpdir), "*1 passed*"])
+
+
+def test_rootdir_wrong_option_arg(testdir):
+    testdir.makepyfile("""
+        import os
+        def test_one():
+            assert 1
+    """)
+
+    result = testdir.runpytest("--rootdir=wrong_dir")
+    result.stderr.fnmatch_lines(["*Directory *wrong_dir* not found. Check your '--rootdir' option.*"])
